@@ -179,12 +179,32 @@ def timesince_limited(d):
 
     :param d: The date to display.
     """
-    interval = datetime.datetime.now() - d
+    today = datetime.datetime.now()
     delta = datetime.timedelta
-    if interval < delta(days=1):
+    interval = today - d
+    if today.strftime('%Y-%m-%d') == d.strftime('%Y-%m-%d'):
         if interval < delta(days=0, hours=1):
             return timesince(d) + ' ago '
         else:
             return d.strftime('%H:%M')
     else:
         return d
+
+
+@register.inclusion_tag('bob/form_horizontal.html')
+def form_horizontal(form, action, method='POST', fugue_icons=False):
+    """
+    Render a horizontal form.
+
+    :param form: The form to render.
+    :param action: The submit URL.
+    :param method: The submit method, either ``"GET"`` or ``"POST"``.
+    :param fugue_icons: Whether to use Fugue or Bootstrap icon.
+    """
+    return {
+        'form': form,
+        'action': action,
+        'method': method,
+        'fugue_icons': fugue_icons,
+    }
+
